#
# spec file for package hamcrest
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           hamcrest
Version:        3.0
Release:        1.3
Summary:        Library of matchers for building test expressions
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://github.com/hamcrest/JavaHamcrest
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
Source2:        https://repo1.maven.org/maven2/org/hamcrest/%{name}/%{version}/%{name}-%{version}.pom
Source3:        https://raw.githubusercontent.com/hamcrest/JavaHamcrest/v%{version}/LICENSE
Source4:        https://raw.githubusercontent.com/hamcrest/JavaHamcrest/v%{version}/README.md
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Provides:       %{name}-core = %{version}
Obsoletes:      %{name}-core < %{version}
Obsoletes:      %{name}-demo < %{version}
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
%endif

%description
Provides a library of matcher objects (also known as constraints or
predicates) allowing 'match' rules to be defined declaratively, to be
used in other frameworks. Typical scenarios include testing frameworks,
mocking libraries and UI validation rules.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml
cp %{SOURCE3} %{SOURCE4} .

%build
%{ant} \
%if %{without tests}
    -Dtest.skip=true \
%endif
    jar javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{name}/all.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{name}/core.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{name}/library.jar

# poms
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} %{SOURCE2} %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar -a "org.hamcrest:hamcrest-all,org.hamcrest:hamcrest-core,org.hamcrest:hamcrest-library"

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%{_javadir}/%{name}
%license LICENSE
%doc README.md

%files javadoc
%license LICENSE
%{_javadocdir}/%{name}

%changelog
* Tue Aug 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.0
  * Breaking Changes
    + From version 3.0, the jar distributed to Maven Central is now
    compiled to Java 1.8 bytecode, and is not compatible with
    previous versions of Java.
    Developers who use Java 1.7 earlier can still depend upon
    hamcrest-2.2.jar.
  * Improvements
    + FileMatchersTest simplification
    + License cleanup
- Removed patches:
  * 0001-Fix-build-with-OpenJDK-11.patch
    + not needed any more
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jun  9 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.2
  * After a long hiatus without releases, this version simplifies
    the packaging of Hamcrest into a single jar. Other big changes
    include Java 9 module compatibility, along with numerous other
    improvements and bug fixes.
  * Breaking Changes
    + Although the class API has not changed since Hamcrest 1.3, the
    way that the project is packaged has changed. Refer to the
    Hamcrest Distributables documentation for more information,
    and in particular the section on Upgrading from Hamcrest 1.x
    + The org.hamcrest.Factory annotation has been removed
    (it should not be used in client code)
  * Improvements
    + AllOf/AnyOf: Pass the matchers to constructor using varargs
    + Matchers.anyOf: Fix generic bounds compatibility for JDK 11
    + AssertionError message is unhelpful when match fails for byte
    type
    + Use platform specific line breaks
    + Build now checks for consistent use of spaces
  * Changes
    + Fix compatibility issue for development with Android D8
    + Fix typo in license name
    + 1.3 compatible constructors for string matchers
    + Fix for split packages with Java 9 modules
    + Documentation updates
    + Add implementation for CharSequence length matcher
    + Fix for TypeSafeDiagnosingMatcher can't detect generic types
    for subclass
    + Renamed IsCollectionContaining to IsIterableContaining
    + Make Hamcrest an OSGI bundle
    + Add StringRegularExpression matcher
    + Fix StringContainsInOrder to detect if a repeated pattern is
    missing
    + Add ArrayAsIterableMatcher
    + Fix description for IsEqualIgnoringCase
    + Fix JavaDoc examples
    + Upgraded to Java 7
    + Build with Gradle
    + Deprecate IsCollectionContaining and IsArrayContainingXXX
    + Removed deprecated methods from previous release
    + Improve mismatch description of hasItem/hasItems
    + General improvements to mismatch descriptions
    + Several JavaDoc improvements and corrections
    + Deprecated several matcher factory methods of the for "isXyz"
    + Fix address doclint errors reported in JDK 1.8
    + Fix Iterable contains in order is null-safe
    + Added equalToObject() (i.e. unchecked) method
    + Fix arrayContaining(null, null) cause NullPointerException
  * Fix string matching on regular expressions
  * Fix isCloseTo() shows wrong delta in mismatch description
  * Fix add untyped version of equalTo, named equalToObject
  * Implement IsEmptyMap, IsMapWithSize
  * Fix IsArray.describeMismatchSafely() should use
    Matcher.describeMismatch
  * Add Matcher implementation for files
  * Fix NPE in IsIterableContainingInOrder
- Removed patches:
  * hamcrest-1.3-build.patch
  * hamcrest-1.3-fork-javac.patch
  * hamcrest-1.3-javadoc.patch
  * hamcrest-1.3-javadoc10.patch
  * hamcrest-1.3-javadoc9.patch
  * hamcrest-1.3-no-jarjar.patch
  * hamcrest-1.3-qdox-2.0.patch
  * hamcrest-1.3-random-build-crash.patch
  * hamcrest-reproducible-builds.patch
    + not needed with the new version
- Modified patch:
  * hamcrest-matchers.patch -> 0001-Fix-build-with-OpenJDK-11.patch
    + adapt to the changed context
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * hamcrest-1.3-build.patch
    + Build with source/target levels 8
- Added patch:
  * hamcrest-matchers.patch
    + Fix build with jdk17
* Tue Jan  5 2021 Pedro Monreal <pmonreal@suse.com>
- Make hamcrest build reproducibly [bsc#1120493]
- Add hamcrest-reproducible-builds.patch
* Tue Jan  5 2021 Pedro Monreal <pmonreal@suse.com>
- Fix typo in hamcrest-core description [bsc#1179994]
* Thu Nov 19 2020 Pedro Monreal <pmonreal@suse.com>
- Fix RPM Lint complaint: summary-ended-with-dot
* Tue Nov 17 2020 Pedro Monreal <pmonreal@suse.com>
- Add obsoletes in core to fix updates. [bsc#1174544]
* Wed Oct  2 2019 Fridrich Strba <fstrba@suse.com>
- Remove references to the hamcrest-parent pom and do not
  distribute it
  * useless since we don't build with maven
  * creates problems with gradle connector
* Tue Jan 15 2019 Fridrich Strba <fstrba@suse.com>
- Make jmock and easymock integration opt-in (bsc#1121956)
* Fri Jan  4 2019 Fridrich Strba <fstrba@suse.com>
- Use sources from github, which are accessible
- Do not build the hamcrest-text empty jar
- Split a core package off the main package
- Added patch:
  * hamcrest-1.3-qdox-2.0.patch
    + Fix build against QDox 2.0
- Removed patch:
  * hamcrest-1.3-no-integration.patch
    + Not needed any more since integration is buildable
- Modified patches:
  * hamcrest-1.3-build.patch
  * hamcrest-1.3-fork-javac.patch
  * hamcrest-1.3-javadoc.patch
  * hamcrest-1.3-javadoc10.patch
  * hamcrest-1.3-javadoc9.patch
  * hamcrest-1.3-no-jarjar.patch
  * hamcrest-1.3-random-build-crash.patch
* Mon Dec 18 2017 fstrba@suse.com
- Added patch:
  * hamcrest-1.3-javadoc10.patch
    + Fix build with jdk10's javadoc that ends in error when a
    link cannot be downloaded
* Fri Sep  8 2017 fstrba@suse.com
- Modified patch:
  * hamcrest-1.3-fork-javac.patch
    + Specify java target level 1.6 in order to allow building
    with jdk9
- Specify java source level 1.6 in order to allow building with
  jdk9
- Added patch:
  * hamcrest-1.3-javadoc9.patch
    + fix javadoc errors that are fatal in jdk9
* Mon May 29 2017 tchvatal@suse.com
- Apply patch from fedora:
  * hamcrest-1.3-fork-javac.patch
* Fri May 19 2017 tchvatal@suse.com
- Fix homepage
- Update to build with new javapacakges-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Mon Jul  7 2014 tchvatal@suse.com
- Use junit not junit4
* Mon Jun 16 2014 tchvatal@suse.com
- Add patch to fix random build errors by enforcing single thread.
  * hamcrest-1.3-random-build-crash.patch
* Tue Oct 29 2013 mvyskocil@suse.com
- drop junit from dependencies, it's not needed and cause a build cycle
* Mon Oct 21 2013 mvyskocil@suse.com
- Update to 1.3
  bugfix and feature update, see CHANGES.txt for details
- Removed patches
  * hamcrest-1.1-build.patch
    + renamed to hamcrest-1.3-build.patch
  * hamcrest-1.1-no-jarjar.patch
    + renamed to hamcrest-1.3-no-jarjar.patch
  * hamcrest-1.1-no-integration.patch
    + renamed to hamcrest-1.3-no-integration.patch
- Added patches
  * hamcrest-1.3-javadoc.patch
- Updated poms and added OSGI manifests from Fedora
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Sep  3 2013 mvyskocil@suse.com
- use add_maven_depmap from javapackages-tools
- install non-versioned dirs and jars
* Tue May  5 2009 mvyskocil@suse.cz
- Initial packaging of 1.1 in SUSE (from jpp 5.0)
